@@ -4,6 +4,8 @@
 # procedures that help in implementing those bindings.  The spinbox builds
 # off the entry widget, so it can reuse Entry bindings and procedures.
 #
+# RCS: @(#) $Id: spinbox.tcl,v 1.9 2005/07/25 09:06:00 dkf Exp $
+#
 # Copyright (c) 1992-1994 The Regents of the University of California.
 # Copyright (c) 1994-1997 Sun Microsystems, Inc.
 # Copyright (c) 1999-2000 Jeffrey Hobbs
@@ -73,6 +75,11 @@ bind Spinbox <<PasteSelection>> {
     }
 }
 
+bind Spinbox <<TraverseIn>> {
+    %W selection range 0 end 
+    %W icursor end 
+}
+
 # Standard Motif bindings:
 
 bind Spinbox <1> {
@@ -210,14 +217,13 @@ bind Spinbox <Escape> {# nothing}
 bind Spinbox <Return> {# nothing}
 bind Spinbox <KP_Enter> {# nothing}
 bind Spinbox <Tab> {# nothing}
-
 if {[tk windowingsystem] eq "aqua"} {
-	bind Spinbox <Command-KeyPress> {# nothing}
+    bind Spinbox <Command-KeyPress> {# nothing}
 }
 
 # On Windows, paste is done using Shift-Insert.  Shift-Insert already
 # generates the <<Paste>> event, so we don't need to do anything here.
-if {[tk windowingsystem] ne "win32"} {
+if {$tcl_platform(platform) ne "windows"} {
     bind Spinbox <Insert> {
 	catch {::tk::EntryInsert %W [::tk::GetSelection %W PRIMARY]}
     }
@@ -494,7 +500,9 @@ proc ::tk::spinbox::MouseSelect {w x {cursor {}}} {
 proc ::tk::spinbox::Paste {w x} {
     $w icursor [::tk::spinbox::ClosestGap $w $x]
     catch {$w insert insert [::tk::GetSelection $w PRIMARY]}
-    if {"disabled" eq [$w cget -state]} {focus $w}
+    if {"disabled" eq [$w cget -state]} {
+	focus $w
+    }
 }
 
 # ::tk::spinbox::Motion --
